@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test.rb 220 2008-06-17 05:45:58Z tommy $
+# $Id: test.rb 244 2009-02-01 08:43:39Z tommy $
 
 require "test/unit"
 require "./mysql.o"
@@ -16,7 +16,7 @@ class TC_Mysql < Test::Unit::TestCase
   end
 
   def test_version()
-    assert_equal(20706, Mysql::VERSION)
+    assert_equal(20801, Mysql::VERSION)
   end
 
   def test_init()
@@ -144,6 +144,7 @@ class TC_Mysql2 < Test::Unit::TestCase
 
   def test_query_with_block()
     if @m.server_version >= 40100 then
+      @m.set_server_option(Mysql::OPTION_MULTI_STATEMENTS_ON)
       expect = [["1","2","3"], ["4","5","6"]]
       @m.query("select 1,2,3; select 4,5,6") {|res|
         assert_equal(1, res.num_rows)
@@ -169,6 +170,13 @@ class TC_Mysql2 < Test::Unit::TestCase
     end
   end
 
+  def test_query_with_block_single()
+    @m.query("select 1,2,3") {|res|
+      assert_equal(1, res.num_rows)
+      assert_equal(["1","2","3"], res.fetch_row)
+    }
+  end
+
   def test_set_server_option()
     if @m.server_version >= 40101 then
       assert_equal(@m, @m.set_server_option(Mysql::OPTION_MULTI_STATEMENTS_ON))
